/*
 * Copyright (C) 2021 ScalAgent Distributed Technologies
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA.
 *
 * Original developer: ScalAgent Distributed Technologies
 */
package org.objectweb.util.monolog.api;

import java.util.logging.Level;

/**
 * This classe wraps old Monolog's BasicLevel on JavaLog Level.
 * It avoids the use of JavaLog Level objects in Joram code.
 */
public class BasicLevel {
  public static int BADLEVEL = 0;
  public static int INHERITLEVEL = -2;
  
//  public static Level FATAL = Level.SEVERE;
//  public static Level ERROR = Level.SEVERE;
//  public static Level WARN = Level.WARNING;
//  public static Level INFO = Level.INFO;
//  public static Level DEBUG = Level.FINEST;

  public static Level FATAL = new MonologLevel("FATAL", Level.SEVERE.intValue());
  public static Level ERROR   = new MonologLevel("ERROR",   950);
  public static Level WARN   = new MonologLevel("WARN",   Level.WARNING.intValue());
  public static Level INFO   = new MonologLevel("INFO",   Level.INFO.intValue());
  public static Level DEBUG   = new MonologLevel("DEBUG",   Level.FINEST.intValue());
  
  public static void initialize() {}
  
  public static int getIntLevel(String name) {
    if (name.equals("BasicLevel.DEBUG") || name.equals("DEBUG"))
      return BasicLevel.DEBUG.intValue();
    else if (name.equals("BasicLevel.ERROR") || name.equals("ERROR"))
      return BasicLevel.ERROR.intValue();
    else if (name.equals("BasicLevel.FATAL") || name.equals("FATAL"))
      return BasicLevel.FATAL.intValue();
    else if (name.equals("BasicLevel.INFO") || name.equals("INFO"))
      return BasicLevel.INFO.intValue();
    else if (name.equals("BasicLevel.WARN") || name.equals("WARN"))
      return BasicLevel.WARN.intValue();
    Level level = Level.parse(name);
    if (level != null)
      return level.intValue();
    return BADLEVEL;
  }

  public static Level parse(String name) {
    return Level.parse(name);
  }
  
  public static Level fromIntLevel(int level) {
    if (level == FATAL.intValue()) {
      return FATAL;
    } else if (level == ERROR.intValue()) {
      return ERROR;
    } else if (level == WARN.intValue()) {
      return WARN;
    } else if (level == INFO.intValue()) {
      return INFO;
    } else if (level == DEBUG.intValue()) {
      return DEBUG;
    }
    return null;
  }

  public static int getIntLevel(Level level) {
    return level.intValue();
  }
}
