/*
 * Copyright (C) 2001 - 2021 ScalAgent Distributed Technologies
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA.
 *
 * Initial developer(s): ScalAgent Distributed Technologies
 * Contributor(s): 
 */
package fr.dyade.aaa.agent;

public interface SCServerMBean {
  public short getServerId();
  public String getName();

  public void start();
  public void stop();
  public void shutdown();

  public int getStatus();
  public String getStatusInfo();

  public String[] getServers();
  
  public void dumpServerState(String path);
  public void dumpAttributes(String name, String path, boolean threaddump);
  
  /**
   * Sets the DEBUG level for the specified logger.
   * 
   * @param classname The logger name.
   */
  public void debug(String classname);
  
  /**
   * Sets the INFO level for the specified logger.
   * 
   * @param classname The logger name.
   */
  public void info(String classname);
  
  /**
   * Sets the WARN level for the specified logger.
   * 
   * @param classname The logger name.
   */
  public void warn(String classname);
  
  /**
   * Sets the ERROR level for the specified logger.
   * 
   * @param classname The logger name.
   */
  public void error(String classname);
  
  /**
   * Sets the FATAL level for the specified logger.
   * 
   * @param classname The logger name.
   */
  public void fatal(String classname);
  
  /**
   * Set the given level for the specified logger.
   * 
   * @param classname The logger name.
   * @param level     The level name
   */
  void setLoggerLevel(String classname, String level);

  /**
   * Sets the INHERIT level for the specified logger.
   * 
   * @param classname The logger name.
   */
  public void clearLoggerLevel(String classname);
  
//  /**
//   * Freezes the Transaction module.
//   * 
//   * @param timeout
//   * @throws InterruptedException
//   */
//  // TODO (AF): Needed for test/debug, do not commit.
//  public void freeze(long timeout) throws InterruptedException;
  
  /**
   * Backups the content of Transaction module.
   * Produces a generic Backup/Restore file containing all living objects.
   * 
   * @param path  Directory path to store the backup.
   * @return the name of created backup file.
   * @throws Exception An error occurs during backup.
   */
  public String backup(String path) throws Exception;
}
